@@ -19,7 +19,7 @@ TimeLabelsZone::TimeLabelsZone(QWidget *parent, const PrefsPtr &preferences, Age
     : QWidget(parent)
     , mAgenda(agenda)
     , mPrefs(preferences)
-    , mParent(qobject_cast<AgendaView * >(parent))
+    , mParent(qobject_cast<AgendaView *>(parent))
 {
     mTimeLabelsLayout = new QHBoxLayout(this);
     mTimeLabelsLayout->setContentsMargins(0, 0, 0, 0);
@@ -66,8 +66,8 @@ void TimeLabelsZone::init()
 
 void TimeLabelsZone::addTimeLabels(const QTimeZone &zone)
 {
-    auto *area = new QScrollArea(this);
-    auto *labels = new TimeLabels(zone, 24, this);
+    auto area = new QScrollArea(this);
+    auto labels = new TimeLabels(zone, 24, this);
     mTimeLabelsList.prepend(area);
     area->setWidgetResizable(true);
     area->setWidget(labels);
@@ -85,16 +85,14 @@ void TimeLabelsZone::setupTimeLabel(QScrollArea *area)
 {
     if (mAgenda && mAgenda->verticalScrollBar()) {
         // Scrolling the agenda will scroll the timelabel
-        connect(mAgenda->verticalScrollBar(), &QAbstractSlider::valueChanged,
-                area->verticalScrollBar(), &QAbstractSlider::setValue);
+        connect(mAgenda->verticalScrollBar(), &QAbstractSlider::valueChanged, area->verticalScrollBar(), &QAbstractSlider::setValue);
         // and vice-versa. ( this won't loop )
-        connect(area->verticalScrollBar(), &QAbstractSlider::valueChanged,
-                mAgenda->verticalScrollBar(), &QAbstractSlider::setValue);
+        connect(area->verticalScrollBar(), &QAbstractSlider::valueChanged, mAgenda->verticalScrollBar(), &QAbstractSlider::setValue);
 
         area->verticalScrollBar()->setValue(mAgenda->verticalScrollBar()->value());
     }
 
-    auto *timeLabels = static_cast<TimeLabels *>(area->widget());
+    auto timeLabels = static_cast<TimeLabels *>(area->widget());
     timeLabels->setAgenda(mAgenda);
 
     // timelabel's scroll is just a slave, this shouldn't be here
@@ -116,7 +114,7 @@ int TimeLabelsZone::preferedTimeLabelsWidth() const
 void TimeLabelsZone::updateAll()
 {
     for (QScrollArea *area : qAsConst(mTimeLabelsList)) {
-        auto *timeLabel = static_cast<TimeLabels *>(area->widget());
+        auto timeLabel = static_cast<TimeLabels *>(area->widget());
         timeLabel->updateConfig();
     }
 }
@@ -141,7 +139,7 @@ void TimeLabelsZone::updateTimeLabelsPosition()
     if (mAgenda) {
         const auto lst = timeLabels();
         for (QScrollArea *area : lst) {
-            auto *label = static_cast<TimeLabels *>(area->widget());
+            auto label = static_cast<TimeLabels *>(area->widget());
             const int adjustment = mAgenda->contentsY();
             // y() is the offset to our parent (QScrollArea)
             // and gets negative as we scroll
