@@ -1,66 +1,51 @@
 /*
-  Copyright (c) 1999 Preston Brown <pbrown@kde.org>
-  Copyright (c) 2000,2001 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (C) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
-  Author: Kevin Krammer, krake@kdab.com
+  SPDX-FileCopyrightText: 1999 Preston Brown <pbrown@kde.org>
+  SPDX-FileCopyrightText: 2000, 2001 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileContributor: Kevin Krammer <krake@kdab.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 #ifndef EVENTVIEWS_EVENTVIEW_H
 #define EVENTVIEWS_EVENTVIEW_H
 
 #include "eventviews_export.h"
 
+#include <Akonadi/Calendar/ETMCalendar>
 #include <Collection>
 #include <Item>
-#include <Akonadi/Calendar/ETMCalendar>
 
-#include <KCalCore/Incidence>
-#include <KCalCore/Todo>
+#include <KCalendarCore/Incidence>
+#include <KCalendarCore/Todo>
 
-#include <QWidget>
-#include <QSet>
 #include <QByteArray>
 #include <QDate>
+#include <QSet>
+#include <QWidget>
 
-namespace CalendarSupport {
+namespace CalendarSupport
+{
 class CollectionSelection;
 class KCalPrefs;
 }
 
-namespace Akonadi {
+namespace Akonadi
+{
 class IncidenceChanger;
 }
 
 class KCheckableProxyModel;
 class KConfigGroup;
 
-namespace EventViews {
-enum {
-    BUSY_BACKGROUND_ALPHA = 70
-};
+namespace EventViews
+{
+enum { BUSY_BACKGROUND_ALPHA = 70 };
 
 class EventViewPrivate;
 class Prefs;
-typedef QSharedPointer<Prefs> PrefsPtr;
-typedef QSharedPointer<CalendarSupport::KCalPrefs> KCalPrefsPtr;
+using PrefsPtr = QSharedPointer<Prefs>;
+using KCalPrefsPtr = QSharedPointer<CalendarSupport::KCalPrefs>;
 
 /**
   EventView is the abstract base class from which all other calendar views
@@ -128,7 +113,7 @@ public:
 
     /**
       Return calendar object of this view.
-      TODO: replace with a version that returns a KCalCore::Calendar so it
+      TODO: replace with a version that returns a KCalendarCore::Calendar so it
             can be used in different environments.
             see agendaview for example calendar2(incidence)
     */
@@ -155,7 +140,7 @@ public:
       probably only select a single event at a time, but some may be able
       to select more than one.
     */
-    virtual KCalCore::DateList selectedIncidenceDates() const = 0;
+    virtual KCalendarCore::DateList selectedIncidenceDates() const = 0;
 
     /**
        Returns the start of the selection, or an invalid QDateTime if there is no selection
@@ -265,7 +250,7 @@ public:
     Q_REQUIRED_RESULT QDateTime actualStartDateTime() const;
     Q_REQUIRED_RESULT QDateTime actualEndDateTime() const;
 
-    Q_REQUIRED_RESULT int showMoveRecurDialog(const KCalCore::Incidence::Ptr &incidence, const QDate &date);
+    Q_REQUIRED_RESULT int showMoveRecurDialog(const KCalendarCore::Incidence::Ptr &incidence, const QDate &date);
 
     /**
       Handles key events, opens the new event dialog when enter is pressed, activates type ahead.
@@ -364,7 +349,7 @@ Q_SIGNALS:
      * selected dates has changed.
      *   @param datelist the new list of selected dates
      */
-    void datesSelected(const KCalCore::DateList &datelist);
+    void datesSelected(const KCalendarCore::DateList &datelist);
 
     /**
      * Emitted when an event is moved using the mouse in an agenda
@@ -394,18 +379,18 @@ Q_SIGNALS:
     void deleteIncidenceSignal(const Akonadi::Item &);
 
     /**
-    * instructs the receiver to cut the Incidence
-    */
+     * instructs the receiver to cut the Incidence
+     */
     void cutIncidenceSignal(const Akonadi::Item &);
 
     /**
-    * instructs the receiver to copy the incidence
-    */
+     * instructs the receiver to copy the incidence
+     */
     void copyIncidenceSignal(const Akonadi::Item &);
 
     /**
-    * instructs the receiver to paste the incidence
-    */
+     * instructs the receiver to paste the incidence
+     */
     void pasteIncidenceSignal();
 
     /**
@@ -469,12 +454,12 @@ private:
     void onCollectionChanged(const Akonadi::Collection &, const QSet<QByteArray> &);
 
 protected:
-    bool makesWholeDayBusy(const KCalCore::Incidence::Ptr &incidence) const;
+    bool makesWholeDayBusy(const KCalendarCore::Incidence::Ptr &incidence) const;
     Akonadi::IncidenceChanger *changer() const;
 
     /**
-      * reimplement to read view-specific settings.
-      */
+     * reimplement to read view-specific settings.
+     */
     virtual void doRestoreConfig(const KConfigGroup &configGroup);
 
     /**
@@ -497,8 +482,7 @@ protected:
      * month to show when the week crosses months.  It's a QDate instead of
      * uint so it can be easily fed to KCalendarSystem's functions.
      */
-    virtual QPair<QDateTime, QDateTime> actualDateRange(
-        const QDateTime &start, const QDateTime &end, const QDate &preferredMonth = QDate()) const;
+    virtual QPair<QDateTime, QDateTime> actualDateRange(const QDateTime &start, const QDateTime &end, const QDate &preferredMonth = QDate()) const;
     /*
     virtual void incidencesAdded( const Akonadi::Item::List &incidences );
     virtual void incidencesAboutToBeRemoved( const Akonadi::Item::List &incidences );
