@@ -310,8 +310,9 @@ IncidenceMonthItem::IncidenceMonthItem(MonthScene *monthScene,
 
     // first set to 0, because it's used in startDate()
     mRecurDayOffset = 0;
-    if ((mIncidence->recurs() || mIncidence->recurrenceId().isValid()) && startDate().isValid() && recurStartDate.isValid()) {
-        mRecurDayOffset = startDate().daysTo(recurStartDate);
+    const auto incidenceStart = mIncidence->dtStart().toLocalTime().date();
+    if ((mIncidence->recurs() || mIncidence->recurrenceId().isValid()) && incidenceStart.isValid() && recurStartDate.isValid()) {
+        mRecurDayOffset = incidenceStart.daysTo(recurStartDate);
     }
 }
 
@@ -358,9 +359,10 @@ QDate IncidenceMonthItem::realEndDate() const
     }
 
     QDateTime dt = mIncidence->dateTime(KCalendarCore::Incidence::RoleDisplayEnd);
-    if (!mIncidence->allDay()) {
-        // If dt's time portion is 00:00, the incidence ends on the previous day.
-        dt = dt.addSecs(-1);
+    if (!mIncidence->allDay() && dt > mIncidence->dateTime(KCalendarCore::Incidence::RoleDisplayStart)) {
+        // If dt's time portion is 00:00:00, the incidence ends on the previous day
+        // unless it also starts at 00:00:00 (a duration of 0).
+        dt = dt.addMSecs(-1);
     }
     const QDate end = dt.toLocalTime().date();
 
